@@ -121,6 +121,13 @@ politeness<-function(text, parser=c("none","spacy"),
   features[["For.You"]]<-textcounter(" for you ",sets[["clean"]], num_mc_cores=num_mc_cores)
   features[["Reasoning"]]<-textcounter(c("reason", "why i ", "why we ", "explain", "caused","because"),sets[["clean"]],
                                        num_mc_cores=num_mc_cores)
+
+  features[["Contrast.Conjunction"]]<-textcounter(c("but","however","instead",
+                                                    "although","even though",
+                                                    "despite","and yet",
+                                                    "nevertheless","nonetheless"),sets[["clean"]],
+                                                  num_mc_cores=num_mc_cores)
+
   features[["Reassurance"]]<-textcounter(c("is okay", "not worry", "no big deal", "not a big deal", "no problem",
                                            "no worries", "is fine", "you are good", "it's fine", "it's okay") ,sets[["clean"]],
                                          num_mc_cores=num_mc_cores)
@@ -134,17 +141,22 @@ politeness<-function(text, parser=c("none","spacy"),
                                     num_mc_cores=num_mc_cores)+
                           textcounter(c("good morning", "good evening", "good afternoon"),sets[["clean"]],
                                       num_mc_cores=num_mc_cores))
-  features[["Please"]]<-1*(grepl("please",sets[["c.words"]],fixed=TRUE))
+
+  features[["Please"]]<-textcounter("please",sets[["c.words"]],words=TRUE,
+                                    num_mc_cores=num_mc_cores)
 
   features[["First.Person.Plural"]]<-textcounter(c("we", "our", "ours", "us", "ourselves"),sets[["c.words"]],words=TRUE,
                                                  num_mc_cores=num_mc_cores)
+
   features[["First.Person.Single"]]<-textcounter(c("i","my","mine","myself"),sets[["c.words"]],words=TRUE,
                                                  num_mc_cores=num_mc_cores)
+
   features[["Second.Person"]]<-textcounter(c("you","your","yours","yourself", "yourselves"),sets[["c.words"]],words=TRUE,
                                            num_mc_cores=num_mc_cores)
+
   #if(parser[1]=="none"){
   if(parser[1]!="spacy"){
-    cat("Warning: Please install SpaCy first, using the spacyr R package. This is an INCOMPLETE version of the package.")
+    cat("Warning: Please install and initialize SpaCy, using the spacyr R package. This is an INCOMPLETE version of the package.")
     features[["Positive.Emotion"]]<-textcounter(positive_list,sets[["c.words"]],words=TRUE, num_mc_cores=num_mc_cores)
     features[["Negative.Emotion"]]<-textcounter(negative_list,sets[["c.words"]],words=TRUE, num_mc_cores=num_mc_cores)
     features[["Questions"]]<-textcounter("?",text, num_mc_cores=num_mc_cores)
@@ -254,34 +266,40 @@ politeness<-function(text, parser=c("none","spacy"),
 
     features[["Apology"]]<-(textcounter(c("woops","oops","whoops"),sets[["unneg.words"]],words=TRUE,
                                         num_mc_cores=num_mc_cores)
-                            +textcounter(c("acomp(am, sorry)","root(root, sorry)",
+                            +textcounter(c("acomp(am, sorry)","acomp('m, sorry)",
+                                           "root(root, sorry)",
                                            "nsubj(apologize, we)","nsubj(apologize, i)",
                                            "nsubj(regret, i)", "nsubj(regret, we)",
                                            "dobj(excuse, me)",
                                            "poss(forgiveness, your)",
                                            "dobj(forgive, me)"),sets[["p.unnegs"]], words=TRUE,
                                          num_mc_cores=num_mc_cores)
+                            +min(sum(textcounter("nsubj(are, we)",sets[["p.unnegs"]],words=TRUE)),
+                                 sum(textcounter("acomp(are, sorry)",sets[["p.unnegs"]],words=TRUE)))
+                            +min(sum(textcounter("nsubj('re, we)",sets[["p.unnegs"]],words=TRUE)),
+                                 sum(textcounter("acomp('re, sorry)",sets[["p.unnegs"]],words=TRUE)))
                             # "I would like to apologize" - "I want to apologize" - "would you like to apologize"
-                            # "We are sorry" - "they are sorry"
 
     )
     features[["Truth.Intensifier"]]<-(textcounter(c("really", "actually", "honestly", "surely"),sets[["c.words"]],words=TRUE,
                                                   num_mc_cores=num_mc_cores)
                                       +textcounter(c("det(point, the)","det(reality, the)","det(truth, the)","pobj(fact, in)","case(fact, in)"),sets[["p.nonum"]], words=TRUE,
                                                    num_mc_cores=num_mc_cores))
-    features[["Affirmation"]]<-textcounter(paste0(c("yeah","yes","ok","okay","perfect","fine","wow","great","amazing","fantastic",
-                                                    "good","nice","interesting","cool","excellent","awesome"),"-1"),sets[["w.nums"]],words=TRUE,
-                                           num_mc_cores=num_mc_cores)
     features[["Adverb.Limiter"]]<-unlist(lapply(sets[["p.nonum"]] ,function(x) sum(grepl("advmod",unlist(x))&
                                                                                      (grepl("just)",unlist(x),fixed=TRUE)
                                                                                       |grepl("only)",unlist(x),fixed=TRUE)
                                                                                       |grepl("merely)",unlist(x),fixed=TRUE)
                                                                                       |grepl("simply)",unlist(x),fixed=TRUE)))
     ))
-
-    features[["Conjunction.Start"]]<-textcounter(paste0(c("so","then","and","but","or"),"-1"),sets[["w.nums"]],words=TRUE,
-                                                 num_mc_cores=num_mc_cores)
   }
+  features[["Affirmation"]]<-textcounter(c("yeah","yes","ok","okay","perfect","fine","wow","great","amazing"),
+                                         sets[["c.words"]],words=TRUE,start=TRUE,
+                                         num_mc_cores=num_mc_cores)
+
+  # listed at the end for backward compatibility
+  features[["Conjunction.Start"]]<-textcounter(c("so","then","and","but","or","however"),
+                                               sets[["c.words"]],words=TRUE,start=TRUE,
+                                               num_mc_cores=num_mc_cores)
 
   if(metric[1]=="binary"){
     features<-parallel::mclapply(features, function(x) 1*(x>0), mc.cores=num_mc_cores)
